@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,7 +10,7 @@ using namespace Qt::Literals::StringLiterals;
 #include "kmail_debug.h"
 #include "kmkernel.h"
 #include <KMime/Message>
-#include <MessageComposer/Composer>
+#include <MessageComposer/ComposerJob>
 #include <MessageComposer/MessageHelper>
 #include <MessageCore/StringUtil>
 #include <TemplateParser/TemplateParserJob>
@@ -71,7 +71,7 @@ void HandleClickedUrlJob::start()
 
 void HandleClickedUrlJob::slotOpenComposer()
 {
-    KMail::Composer *win = KMail::makeComposer(mMsg, false, false, KMail::Composer::New, mIdentity);
+    KMail::Composer *win = KMail::makeComposer(mMsg, false, false, KMail::Composer::TemplateContext::New, mIdentity);
     win->setFocusToSubject();
     win->setCollectionForNewMessage(mCurrentCollection);
     win->show();
