@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2011-2024 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2025 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  */
@@ -140,10 +140,11 @@ QVariant KMSearchMessageModel::entityData(const Akonadi::Item &item, int column,
     }
 
     // The Collection column is first and is added by this model
-    if (column == Collection) {
+    if (column == int(KMSearchMessageModel::Column::Collection)) {
         if (role == Qt::DisplayRole || role == Qt::EditRole) {
-            if (item.storageCollectionId() >= 0) {
-                return fullCollectionPath(item.storageCollectionId());
+            const Akonadi::Collection::Id collectionId = item.storageCollectionId();
+            if (collectionId >= 0) {
+                return fullCollectionPath(collectionId);
             }
             return fullCollectionPath(item.parentCollection().id());
         }
@@ -156,7 +157,7 @@ QVariant KMSearchMessageModel::entityData(const Akonadi::Item &item, int column,
 
 QVariant KMSearchMessageModel::entityHeaderData(int section, Qt::Orientation orientation, int role, HeaderGroup headerGroup) const
 {
-    if (orientation == Qt::Horizontal && role == Qt::DisplayRole && section == Collection) {
+    if (orientation == Qt::Horizontal && role == Qt::DisplayRole && section == int(KMSearchMessageModel::Column::Collection)) {
         return i18nc("@title:column, folder (e.g. email)", "Folder");
     }
     return Akonadi::MessageModel::entityHeaderData((section - 1), orientation, role, headerGroup);
